@@ -7,7 +7,7 @@ use Socket;
 use integer;
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use constant PROGRAM_VERSION => "1.2.0b4-Perl";
 use constant MODIFICATION_DATE => "16-03-2006";
@@ -84,34 +84,32 @@ eval {
 };
 
 # Lookups for loading.
-my %mcrypts =	(	ENCRYPT_DES,		"DES",
-			ENCRYPT_3DES,		"3DES",
-			ENCRYPT_CAST128,  	"CASE128",
-			ENCRYPT_CAST256,  	"CASE256",
-			ENCRYPT_XTEA,  		"XTEA",
-			ENCRYPT_3WAY, 	 	"3WAY",
-			ENCRYPT_BLOWFISH,	"BLOWFISH",
-			ENCRYPT_TWOFISH,	"TWOFISH",
-			ENCRYPT_LOKI97,		"LOKI97",
-			ENCRYPT_RC2,		"RC2",
-			ENCRYPT_ARCFOUR,	"ARCFOUR",
-			ENCRYPT_RC6,		"RC6",
-			ENCRYPT_RIJNDAEL128,	"RIJNDAEL128",
-			ENCRYPT_RIJNDAEL192,	"RIJNDAEL192",
-			ENCRYPT_RIJNDAEL256,	"RIJNDAEL256",
-			ENCRYPT_MARS,		"MARS",
-			ENCRYPT_PANAMA,		"PANAMA",
-			ENCRYPT_WAKE,		"WAKE",
-			ENCRYPT_SERPENT,	"SERPENT",
-			ENCRYPT_IDEA,		"IDEA",
-			ENCRYPT_ENIGMA,		"ENIGMA",
-			ENCRYPT_GOST,		"GOST",
-			ENCRYPT_SAFER64,	"SAFER64",
-			ENCRYPT_SAFER128,	"SAFER128",
-			ENCRYPT_SAFERPLUS,	"SAFERPLUS",
-		);
-
-
+my %mcrypts =   (       ENCRYPT_DES,            "des",
+                        ENCRYPT_3DES,           "3des",
+                        ENCRYPT_CAST128,        "cast-128",
+                        ENCRYPT_CAST256,        "cast-256",
+                        ENCRYPT_XTEA,           "xtea",
+                        ENCRYPT_3WAY,           "threeway",
+                        ENCRYPT_BLOWFISH,       "blowfish",
+                        ENCRYPT_TWOFISH,        "twofish",
+                        ENCRYPT_LOKI97,         "loki97",
+                        ENCRYPT_RC2,            "rc2",
+                        ENCRYPT_ARCFOUR,        "arcfour",
+                        ENCRYPT_RC6,            "rc6",
+                        ENCRYPT_RIJNDAEL128,    "rijndael-128",
+                        ENCRYPT_RIJNDAEL192,    "rijndael-192",
+                        ENCRYPT_RIJNDAEL256,    "rijndael-256",
+                        ENCRYPT_MARS,           "mars",
+                        ENCRYPT_PANAMA,         "panama",
+                        ENCRYPT_WAKE,           "wake",
+                        ENCRYPT_SERPENT,        "serpent",
+                        ENCRYPT_IDEA,           "idea",
+                        ENCRYPT_ENIGMA,         "engima",
+                        ENCRYPT_GOST,           "gost",
+                        ENCRYPT_SAFER64,        "safer-sk64",
+                        ENCRYPT_SAFER128,       "safer-sk128",
+                        ENCRYPT_SAFERPLUS,      "saferplus",
+                );
 
 sub send_nsca {
   my $package = shift;
@@ -401,15 +399,17 @@ sub _encrypt_mcrypt {
      # Initialise the routine
      if( defined( $mcrypts{$encryption_method} ) ){
         # Load the routine.
-        my $routine = 'Mcrypt::' . $mcrypts{$encryption_method};
+        my $routine = $mcrypts{$encryption_method};
         eval {
            # This sometimes dies with 'mcrypt is not of type MCRYPT'.
-           my $td = Mcrypt->new( algorithm => $routine, mode => 'Mcrypt::CFB', verbose => 1 );
+           my $td = Mcrypt->new( algorithm => $routine, mode => 'cfb', verbose => 0 );
            my $key = $password;
-           my $iv = $iv_salt;
+           my $iv = substr $iv_salt, 0, $td->{IV_SIZE};
            if( defined( $td ) ){
                $td->init($key, $iv);
-               $crypted = $td->encrypt( $data_packet_string );
+	       for (my $i = 0; $i < length( $data_packet_string ); $i++ ) {
+		 $crypted .= $td->encrypt( substr $data_packet_string, 0+$i, 1 );
+	       }
                $td->end();
            }
            $evalok++;
